"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var DanmaTrack = /** @class */ (function () {
    function DanmaTrack(danmuPool, danmaTrackConfig) {
        this.mDanmaMessages = new Array();
        this.mTrackInfo = {
            maxWidth: 0,
            top: 0,
            height: 0
        };
        this.mDanmuTrackConfig = {
            top: 0,
            height: 0
        };
        this.mDanmuPool = danmuPool;
        this.initConfig(danmaTrackConfig);
    }
    DanmaTrack.prototype.setDanmaku = function (danmaku) {
        this.mDanmaku = danmaku;
    };
    DanmaTrack.prototype.initConfig = function (danmaTrackConfig) {
        this.mDanmuTrackConfig = danmaTrackConfig;
        this.mTrackInfo.top = danmaTrackConfig.top;
        this.mTrackInfo.height = danmaTrackConfig.height;
    };
    DanmaTrack.prototype.render = function (ctx) {
        this.refreshMessage(ctx);
        for (var i = 0; i < this.mDanmaMessages.length; i++) {
            var currentDanmaMessage = this.mDanmaMessages[i];
            currentDanmaMessage.onBaseMeasure(ctx, this.mTrackInfo);
            currentDanmaMessage.onBaseLayout(ctx, this.mTrackInfo);
            currentDanmaMessage.onBaseDraw(ctx, this.mTrackInfo);
            currentDanmaMessage.onBaseDestroyed();
            if (i === this.mDanmaMessages.length - 1) {
                this.mTrackInfo.maxWidth =
                    currentDanmaMessage.position.left + currentDanmaMessage.size.width;
            }
        }
    };
    DanmaTrack.prototype.refreshMessage = function (ctx) {
        this.removeMessage();
        this.AddMessage(ctx);
    };
    DanmaTrack.prototype.AddMessage = function (ctx) {
        if (this.mTrackInfo.maxWidth < ctx.canvas.width - 10) {
            var msg = this.mDanmuPool.getMessage();
            if (msg) {
                console.log(msg);
                this.mDanmaMessages.push(msg);
            }
        }
    };
    DanmaTrack.prototype.removeMessage = function () {
        this.mDanmaMessages = this.mDanmaMessages.filter(function (item) { return !item.distoryed; });
    };
    return DanmaTrack;
}());
exports.DanmaTrack = DanmaTrack;
//# sourceMappingURL=DanmaTrack.js.map